@@ -2,8 +2,12 @@
 compatibility with MonetDBLite
 """
 from warnings import warn
+from typing import List, Tuple
+from pandas import DataFrame
 
 from monetdbe.dbapi2 import connect
+from monetdbe.cursor import Cursor
+from monetdbe.connection import Connection
 
 
 def make_connection(*args, **kwargs):
@@ -22,16 +26,27 @@ def init(_: str):
     warn("init() is deprecated and will be removed from future versions")
 
 
-def sql(query: str):
+def sql(query: str, client=None) -> DataFrame:
     warn("sql() is deprecated and will be removed from future versions")
-    return connect().execute(query)
+    if client:
+        if not isinstance(client, Connection):
+            raise TypeError
+        return client.execute(query).fetchdf()
+    else:
+        return connect().execute(query).fetchdf()
 
 
-def create(*args, **kwargs):
+def create(*args, **kwargs) -> Cursor:
     warn("create() is deprecated and will be removed from future versions")
     return connect().cursor().create(*args, **kwargs)
 
 
-def insert(*args, **kwargs):
+def insert(*args, **kwargs) -> Cursor:
     warn("insert() is deprecated and will be removed from future versions")
-    return connect().cursor().insert(*args, **kwargs)
+    if 'client' in kwargs:
+        client = kwargs.pop('client')
+        if not isinstance(client, Connection):
+            raise TypeError
+    else:
+        client = connect()
+    return client.cursor().insert(*args, **kwargs)
