@@ -9,4 +9,4 @@ class TestDescription(object):
     def test_description_fields(self, monetdbe_cursor):
         monetdbe_cursor.execute('select name from sys.tables')
         assert monetdbe_cursor.description[0][0] == "name"
-        assert monetdbe_cursor.description[0][1] == numpy.dtype('<U')
+        assert monetdbe_cursor.description[0][1] == numpy.dtype('O')
